@@ -56,7 +56,7 @@ impl HttpClient {
             Err(e) => return Err(Web3Error::FailedToSend(e)),
         };
 
-        println!("{:?} headers", res.headers());
+        trace!("response headers {:?}", res.headers());
 
         /// here we attempt to parse the required buffer size out of the response length
         const DEFAULT_BUFFER: usize = 1000000;
